django-myapp
============

A example django package to describe basic structure of
third-party django applications/libraries.

Here is a document to explain way to create django apps
`How to create your first Django library <http://hirokiky.org/tech/create_django_library.html>`_.
